@@ -6,7 +6,7 @@ use Carp;
 use JSON;
 use Archive::Zip qw( :ERROR_CODES :CONSTANTS );
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 use Exporter qw(import);
  
@@ -22,7 +22,7 @@ sub lqm_to_txt {
             $files_converted += _lqm_file_to_txt($_);
         }
     } else {
-        $files_converted += _lqm_file_to_txt($lqm);
+        $files_converted = _lqm_file_to_txt($lqm);
     }
     return $files_converted;
 }
@@ -148,7 +148,7 @@ parses the json file inside, then extracts the category and memo text
 from the Json file.
 
 If the filename of the lqm file contains the original timestamp then that
-is placed in a text header int the text along with the category name. The header
+is placed in a text header in the text along with the category name. The header
 can be disabled by setting the package variable C<$IncludeHeader> to false.
 
 The following functions are available:
